# XeroML

## Description
    XeroML is a test version for analyzing biochemical data developed at KaziLab.

## License
    XeroML is released under the Apache License 2.0. For more details, see the LICENSE file included with the source code.

## Contact
For help and support, please open an issue in the GitHub repository or contact the development team at XeroML@kazilab.se.
